# Alarms for Custom Metrics

custom metrics can be used within Guardian either by creating a new alarm template for an existing resource group or by creating a new resource group.

## Existing Resource Group

You can add custom metrics to existing resource groups by adding the alarm to the resource group template. Override the desired properties of the alarm. Resource [variables](variables.md) can be used to reference values within the template dimensions.

```yaml
Templates:
  Ec2Instance:
    LowDiskSpaceRootVolume:
      # Set the metric namespace
      Namespace: CWAgent
      # Set the metric name
      MetricName: DiskSpaceUsedPercent
      # Set the custom dimentions 
      Dimensions:
        path: '/'
        # Reference the resource Id from the resource group
        host: ${Resource::Id}
        device: 'xvda1'
        fstype: 'ext4'
      # Override the default properties set by the base template
      Statistic: Maximum
      Threshold: 85  
      Period: 60
      EvaluationPeriods: 1
      TreatMissingData: breaching

# create our resource 
Resources:
  Ec2Instance:
    - Id: i-12345678
```

## New Resource Group

when creating alarms for a new resource group you can inherit the Base Alarm template generate the structure of the alarm. The properties can then be overridden in the template. Resource [variables](variables.md) can be used to reference values within the template dimensions.

For example here we are creating an alarm for a disk usage metric generated by the CloudWatch agent on a EC2 instance.

```yaml
Templates:
  CustomGroup:
    # Inherit the base alarm template
    Inherit: Base
    LowDiskSpaceRootVolume:
      # Set the metric namespace
      Namespace: CWAgent
      # Set the metric name
      MetricName: DiskSpaceUsedPercent
      # Set the custom dimentions 
      Dimensions:
        path: '/'
        # Reference the resource Id from the resource group
        host: ${Resource::Id}
        device: 'xvda1'
        fstype: 'ext4'
      # Override the default properties set by the base template
      Statistic: Maximum
      Threshold: 85  
      Period: 60
      EvaluationPeriods: 1
      TreatMissingData: breaching

# create our resource 
Resources:
  CustomGroup:
    - Id: i-12345678
```